@@ -6,24 +6,23 @@ from erminigdates import exdate_to_rexception
 import string
 import time, datetime
 import calendar
+import gpe_event
 
 from utils import *
 
+GPE_DB = os.path.expanduser("~/.gpe/calendar")
+
 class GpeObj:
 
     def init_gpe_params(self):
+        ret = False
         # Connection to the gpecalendar database
-        if os.path.isfile("/home/user/.gpe/calendar"):
-            self.gpeconnection = sqlite.connect('/home/user/.gpe/calendar')
-        elif os.path.isfile("/home/pascal/.gpe/calendar"):
-            self.gpeconnection = sqlite.connect('/home/pascal/.gpe/calendar')
-        elif os.path.isfile('calendar'):
-            self.gpeconnection = sqlite.connect('calendar')
-        else:
-            return False
+        if os.path.isfile(GPE_DB):
+            self.gpeconnection = sqlite.connect(GPE_DB)
+            self.gpecursor = self.gpeconnection.cursor()
+            ret = True
             
-        self.gpecursor = self.gpeconnection.cursor()
-	return True
+	return ret
         
 
     def load_gpe_calendars(self):
@@ -35,11 +34,10 @@ class GpeObj:
         return 1
 
     def isevent(self, eventid):
-        query = "SELECT * FROM events WHERE eventid ='" + eventid + "'"
+        query = "SELECT COUNT(*) AS X  FROM events WHERE eventid ='" + eventid + "'"
         printd("gpe_service.isevent : query : " + query)
         self.gpecursor.execute(query)
-        tmpevents = self.gpecursor.fetchall()
-        if (len(tmpevents) >0):
+        if self.gpecursor.fetchone().X > 0:
             return 1
         else:
             return 0
@@ -48,14 +46,10 @@ class GpeObj:
     def getnewevents_count(self, calendarid):
         """Return the count new events in GPE Calendar
         """
-        printd("gpe_service.getnewevents_count : entering")
-        new_recurrent_events=[]
-        query = "SELECT * FROM events WHERE eventid NOT LIKE '%#%' AND calendar=" + calendarid
-        printd("gpe_service.getnewevents_count : query : " + query)
+        query = "SELECT COUNT(*) AS X FROM events WHERE eventid NOT LIKE '%#%' AND calendar=" + calendarid
         self.gpecursor.execute(query)
-        tmpnewevents = self.gpecursor.fetchall()
-        count = len(tmpnewevents)
-        printd("gpe_service.getnewevents_count : new events count : %s" % (count))
+        count = int(self.gpecursor.fetchone().X)
+        printd("gpe_service.getnewevents_count: new events count : %s" % (count))
         return count
 
     def getnewevents(self, calendarid):
@@ -106,12 +100,12 @@ class GpeObj:
                 location = ''
             if (byday == None): byday = 'NULL';
             if (rexceptions == None): rexceptions = 'NULL';
-            new_recurrent_events.append((uid, eventid, title, description,
+            event = gpe_event.GpeEvent(uid, eventid, title, description,
                                          location, startdate, duration,
                                          recur, rend, rcount, rincrement,
-                                         byday, rexceptions))
+                                         byday, rexceptions)
 
-        printd(str(new_recurrent_events))
+            new_recurrent_events.append(event)
 
         return new_recurrent_events
 
@@ -119,24 +113,18 @@ class GpeObj:
     def getdeletedevents_count(self, calendarid):
         """Return the count deleted events in GPE Calendar
         """
-        printd("gpe_service.getdeletedevents_count : entering")
         new_recurrent_events=[]
-        query = "SELECT eventid FROM events_deleted WHERE \
-                     calendar=" + calendarid + \
-                                    " AND eventid LIKE '%#%'"
-        printd("gpe_service.getdeletedevents_count : query : " + query)
+        query = "SELECT COUNT(*) AS X FROM events_deleted WHERE \
+                     calendar=" + calendarid + " AND eventid LIKE '%#%'"
         self.gpecursor.execute(query)
-        tmpnewevents = self.gpecursor.fetchall()
-        count = len(tmpnewevents)
+        count = int(self.gpecursor.fetchone().X)
         printd("gpe_service.getdeletedevents_count : deleted events count : %s" % (count))
         return count
 
     def getdeletedevents(self, calendarid):
 
         query = "SELECT eventid FROM events_deleted WHERE \
-                     calendar=" + calendarid + \
-                                    " AND eventid LIKE '%#%'"
-        printd(query)
+                     calendar=" + calendarid + " AND eventid LIKE '%#%'"
         self.gpecursor.execute(query)
         newevents = self.gpecursor.fetchall()
         newevents = [x[0] for x in newevents]
@@ -148,14 +136,11 @@ class GpeObj:
     def getupdatedevents_count(self, calendarid, modified_date):
         """Return the count updated events in GPE Calendar
         """
-        printd("gpe_service.getupdatedevents_count : entering")
         new_recurrent_events=[]
-        query = "SELECT * FROM events WHERE eventid LIKE '%#%'"\
+        query = "SELECT COUNT(*) AS X FROM events WHERE eventid LIKE '%#%'"\
                    " AND calendar=" + calendarid + " AND modified > " + modified_date
-        printd("gpe_service.getupdatedevents_count : query : " + query)
         self.gpecursor.execute(query)
-        tmpnewevents = self.gpecursor.fetchall()
-        count = len(tmpnewevents)
+        count = int(self.gpecursor.fetchone().X)
         printd("gpe_service.getupdatedevents_count : updated events count : %s" % (count))
         return count
 
@@ -163,7 +148,6 @@ class GpeObj:
         updatedevents=[]
         query = "SELECT * FROM events WHERE eventid LIKE '%#%'"\
                    " AND calendar=" + calendarid + " AND modified > " + modified_date
-        printd("gpe_service.getupdatedevents : " + query)
         self.gpecursor.execute(query)
         tmp_updated_events = self.gpecursor.fetchall()
         printd("gpe_service.getupdatedevents : GPE new recurrent events : ")
@@ -172,9 +156,9 @@ class GpeObj:
             uid = event[0]
             startdate = event[1]
             duration = event[2]
-            eventid = event[7]
             recur = event[3]
             rend = event[4]
+            eventid = event[7]
             rcount = event[8]
             rincrement = event[9]
             byday = event[11]
@@ -182,12 +166,13 @@ class GpeObj:
 
             # Get infos from calendar table
             query = "SELECT * FROM calendar WHERE uid=" + str(uid)
-            printd(query)
             self.gpecursor.execute(query)    
             data = self.gpecursor.fetchall()
             gpeevents = []
-            if data: gpeevents = [list(row) for row in data]
-            print gpeevents
+            if data: 
+                gpeevents = [list(row) for row in data]
+
+            # XXX Change this to remove try-except constructs
             try:
                 description = "%s" % [x[2] for x in gpeevents \
                                       if "description" in x][0]
@@ -202,12 +187,12 @@ class GpeObj:
                                    if "location" in x][0]
             except:
                 location = ''
-            updatedevents.append((uid, eventid, title, description,
+
+            event = gpe_event.GpeEvent(uid, eventid, title, description,
                                          location, startdate, duration,
                                          recur, rend, rcount, rincrement,
-                                         byday, rexceptions))
-
-        printd(str(updatedevents))
+                                         byday, rexceptions)
+            updatedevents.append(event)
 
         return updatedevents
 
@@ -259,15 +244,15 @@ class GpeObj:
 
         for event in events:
             query = 'DELETE FROM calendar WHERE uid=' + str(event[0])
-            printd (query)
+            printd(query)
             self.gpecursor.execute(query)
             self.gpeconnection.commit()
             query = 'DELETE FROM events WHERE uid=' + str(event[0])
-            printd (query)
+            printd(query)
             self.gpecursor.execute(query)
             self.gpeconnection.commit()
 
-        printd('GPE event deleted :' + eventid)
+        print('GPE event deleted :' + eventid)
         
 
     def delete_deletedevent(self, eventid):
@@ -276,13 +261,10 @@ class GpeObj:
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
 
-        printd('GPE deleted event deleted :' + eventid)    
+        printd('GPE deleted event deleted :' + str(eventid))
 
         
-    def add_event(self, start, duration, recur, rend, calendar,
-                            eventid, rcount, 
-                            rincrement, modified, byday, rexceptions,
-                            title, content, published, location):
+    def add_event(self, event):
         """Add an event in the GPE Calendar database"""
     
         printd("** Entering in gpe.add_recurrent_event()")
@@ -293,13 +275,15 @@ class GpeObj:
             modified, byday, rexceptions)
             VALUES 
             ('%s', '%s', %s, %s, 0, %s, '%s', %s, %s, '%s',  '%s', '%s');""" \
-            % (start, duration, recur, rend, calendar, eventid, \
-                 rcount, rincrement, modified, byday, rexceptions)
+            % (event.start_date(), event.duration(), event.recur(), event.rend(), 
+                    event.calendarid(), event.eventid(), event.rcount(), 
+                    event.rincrement(), event.modified(), event.byday(), 
+                    event.rexceptions())
         printd(query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         self.gpecursor.execute("SELECT uid FROM events WHERE eventid = '" \
-                           + eventid + "' AND calendar=" + calendar)
+                           + event.eventid() + "' AND calendar=" + event.calendarid())
         result = self.gpecursor.fetchall()
         printd("New uid : " + str(result[0][0]))
         query = "insert into calendar (uid, tag, value) VALUES ('" \
@@ -308,27 +292,24 @@ class GpeObj:
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         query = "insert into calendar (uid, tag, value) VALUES ('" \
-            + str(result[0][0]) + "','summary','" + title + "');"
+            + str(result[0][0]) + "','summary','" + event.summary() + "');"
         printd(query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         query = "insert into calendar (uid, tag, value) VALUES ('" \
-            + str(result[0][0]) + "','description','" + content + "');"
+            + str(result[0][0]) + "','description','" + event.description() + "');"
         printd(query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         query = "insert into calendar (uid, tag, value) VALUES ('" \
-            + str(result[0][0]) + "','location','" + location + "');"
+            + str(result[0][0]) + "','location','" + event.location() + "');"
         printd(query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         printd("** Exiting gpe.add_recurrent_event()")
         
     
-    def update_event(self, start, duration, recur, rend, calendar,
-                            eventid, rcount, 
-                            rincrement, modified, byday, rexceptions,
-                            title, content, published, location):
+    def update_event(self, event):
         """Update an event in the GPE Calendar database"""
     
         printd("** Entering in gpe.add_recurrent_event()")
@@ -337,35 +318,38 @@ class GpeObj:
             start='%s', duration='%s', recur='%s', rend=%s, alarm=0,
             calendar='%s', rcount='%s', rincrement='%s',
             modified='%s', byday='%s', rexceptions='%s' WHERE eventid='%s';""" \
-            % (start, duration, recur, rend, calendar, \
-                 rcount, rincrement, modified, byday, rexceptions, eventid)
+            % (event.start_date(), event.duration(), event.recur(), event.rend(),
+                    event.calendarid(), event.rcount(), event.rincrement(), 
+                    event.modified(), event.byday(), event.rexceptions(), 
+                    event.eventid())
         printd("gpe_service.update_event : update query : " + query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         
         self.gpecursor.execute("SELECT uid FROM events WHERE eventid = '" \
-                           + eventid + "' AND calendar=" + calendar)
+                           + event.eventid() + "' AND calendar=" + 
+                           event.calendarid())
         result = self.gpecursor.fetchall()
         uid = str(result[0][0])
         printd("gpe_service.update_event : GPE uid to update : " + uid)
 
         query = """UPDATE calendar SET 
                      value='%s' 
-                     WHERE uid='%s' AND tag='summary';""" % (title, uid)
+                     WHERE uid='%s' AND tag='summary';""" % (event.summary(), uid)
         printd("gpe_service.update_event : update query : " + query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         
         query = """UPDATE calendar SET 
                      value='%s' 
-                     WHERE uid='%s' AND tag='description';""" % (content, uid)
+                     WHERE uid='%s' AND tag='description';""" % (event.description(), uid)
         printd("gpe_service.update_event : update query : " + query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()
         
         query = """UPDATE calendar SET 
                      value='%s' 
-                     WHERE uid='%s' AND tag='location';""" % (location, uid)
+                     WHERE uid='%s' AND tag='location';""" % (event.location(), uid)
         printd("gpe_service.update_event : update query : " + query)
         self.gpecursor.execute(query)
         self.gpeconnection.commit()        
@@ -438,27 +422,27 @@ class GpeObj:
         
     def delete_occurence(self, eventid, occurrence):
         printd("gpe_service : delete_occurence : entering")
-        printd("gpe_service : delete_occurence : eventid : " + eventid)
-        printd("gpe_service : delete_occurence : occurrence : " + occurrence)
+        printd("gpe_service : delete_occurence : eventid : " + str(eventid))
+        printd("gpe_service : delete_occurence : occurrence : " + str(occurrence))
         if 'T' in occurrence : 
             occurrence = str(calendar.timegm(
                                       time.strptime(occurrence,"%Y%m%dT%H%M%S"))) + ","
-            printd("gpe_service : delete_occurence : occurence : " + occurrence)
+            printd("gpe_service : delete_occurence : occurence : " + str(occurrence))
         else:
             occurrence = str((int(time.mktime(time.strptime(
                         occurrence, "%Y%m%d"))))) + ","
-        printd("gpe_service.delete_occurence : occurence : "+ occurrence)
+        printd("gpe_service.delete_occurence : occurence : "+ str(occurrence))
         
         self.gpecursor.execute("SELECT rexceptions FROM events WHERE eventid = '" \
                            + eventid + "'")
         result = self.gpecursor.fetchall()
         printd("gpe_service.delete_occurence : list of exceptions before : "\
-                       + occurrence)
+                       + str(occurrence))
         if (result):
             rexceptions = str(result[0][0])
             rexceptions = rexceptions + ", " + occurrence
             printd("gpe_service.delete_occurence : list of exceptions after : "\
-                           + rexceptions)
+                           + str(rexceptions))
             query = "UPDATE events SET rexceptions='" + rexceptions +\
                                 "' WHERE eventid='" + eventid + "'"
             printd("pe_service.delete_occurence : query : " + query)
